@@ -76,8 +76,23 @@ def setup(**kwargs):
     )
 
     resp = setup.run()
-    click.echo()
-    click.secho(resp, fg='green')
+    data = resp.get('data')
+    if data is None:
+        click.secho(resp['error'], fg='red')
+    else:
+        click.echo()
+        click.secho(
+            f"AWS cluster: {data['cluster_id']} and all associated resources have been created.", fg='green')
+        click.echo()
+        click.secho(
+            "A folder with the files needed to access the cluster has been created on your external Piggy drive.", fg='green')
+        click.echo()
+        click.secho(
+            "Piggy status is awake and available to create address by running piggy address create.", fg='green')
+        click.echo()
+        click.secho(
+            "Run piggy status -sleep whenever your done using AWS CloudHSM to stop AWS from charging your account.", fg='red')
+        click.echo()
 
 
 @piggy.group()
